==> magento-module-saas-order-sync-0.3.0.zip: Core/Merchant/MerchantManager.php <==
<?php

namespace Magento\SaaSOrderSync\Core\Merchant;

use Exception;
use Magento\Framework\Webapi\Exception as WebapiException;
use Magento\SaaSOrderSync\Api\Merchant\GetMerchantDataSummaryResponseInterface;
use Magento\SaaSOrderSync\Api\Merchant\MerchantManagerInterface;
use Magento\SaaSOrderSync\Core\SaaS\SaaSClientResolverInterface;
use Psr\Log\LoggerInterface;

class MerchantManager implements MerchantManagerInterface
{
    private SaaSClientResolverInterface $clientResolver;
    private LoggerInterface $logger;

    public function __construct(SaaSClientResolverInterface $clientResolver, LoggerInterface $logger)
    {
        $this->clientResolver = $clientResolver;
        $this->logger = $logger;
    }


    public function getMerchantDataSummary(): GetMerchantDataSummaryResponseInterface
    {
        try {
            $merchantClient = $this->clientResolver->createMerchantClient();
            ['orders' => $orderSummary] = $merchantClient->getDataSummary();

            return new GetMerchantDataSummaryResponse(new MerchantDataSummaryOrders(
                createdFrom: $orderSummary['createdFrom'] ?? "",
                createdTo: $orderSummary['createdTo'] ?? "",
                totalCount: $orderSummary['totalCount'] ?? 0,
                syncErrorsCount: $orderSummary['syncErrorsCount'] ?? 0)
            );
        } catch (Exception $e) {
            $this->logger->critical("Unexpected error on " . (__METHOD__) . ".", ['exception' => $e]);
            throw new WebapiException(
                __("Unexpected error. Please try again later."),
                httpCode: WebapiException::HTTP_INTERNAL_ERROR
            );
        }
    }
}

==> magento-module-saas-order-sync-0.8.0.zip: Core/Merchant/MerchantManager.php <==
<?php
/************************************************************************
 *
 * ADOBE CONFIDENTIAL
 * ___________________
 *
 * Copyright 2023 Adobe
 * All Rights Reserved.
 *
 * NOTICE: All information contained herein is, and remains
 * the property of Adobe and its suppliers, if any. The intellectual
 * and technical concepts contained herein are proprietary to Adobe
 * and its suppliers and are protected by all applicable intellectual
 * property laws, including trade secret and copyright laws.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from Adobe.
 * ************************************************************************
 */
namespace Magento\SaaSOrderSync\Core\Merchant;

use Exception;
use Magento\Framework\Webapi\Exception as WebapiException;
use Magento\SaaSOrderSync\Api\Merchant\GetMerchantDataSummaryResponseInterface;
use Magento\SaaSOrderSync\Api\Merchant\MerchantManagerInterface;
use Magento\SaaSOrderSync\Core\SaaS\SaaSClientResolverInterface;
use Psr\Log\LoggerInterface;

class MerchantManager implements MerchantManagerInterface
{
    private SaaSClientResolverInterface $clientResolver;
    private LoggerInterface $logger;

    public function __construct(SaaSClientResolverInterface $clientResolver, LoggerInterface $logger)
    {
        $this->clientResolver = $clientResolver;
        $this->logger = $logger;
    }


    public function getMerchantDataSummary(): GetMerchantDataSummaryResponseInterface
    {
        try {
            $merchantClient = $this->clientResolver->createMerchantClient();
            ['orders' => $orderSummary] = $merchantClient->getDataSummary();

            return new GetMerchantDataSummaryResponse(new MerchantDataSummaryOrders(
                createdFrom: $orderSummary['createdFrom'] ?? "",
                createdTo: $orderSummary['createdTo'] ?? "",
                totalCount: $orderSummary['totalCount'] ?? 0,
                syncErrorsCount: $orderSummary['syncErrorsCount'] ?? 0)
            );
        } catch (Exception $e) {
            $this->logger->critical("Unexpected error on " . (__METHOD__) . ".", ['exception' => $e]);
            throw new WebapiException(
                __("Unexpected error. Please try again later."),
                httpCode: WebapiException::HTTP_INTERNAL_ERROR
            );
        }
    }
}
